import logging
import sys

import typer
from pyetl.config.global_settings import DATE_DU_JOUR, GPUC_LOG, TMP
from pyetl.pipeline.gpuc.gpuc import DataSource, Gpuc
from pyetl.tools.klogs import Klogs
from typing_extensions import Annotated

app = typer.Typer()

logger = logging.getLogger(__name__)


@app.command()
def create_structure(
    sftp: bool = False, data_source: Annotated[DataSource, typer.Option(case_sensitive=False)] = DataSource.LDAP.value
):
    Klogs.setup()
    rb = Gpuc.build_csv_structure(sftp=sftp, tag=data_source)
    if rb:
        logger.debug("Création des fichiers structures réalisée avec succès")
        sys.exit(0)
    else:
        logger.error("Une erreur est survenue")
        sys.exit(1)


@app.command()
def create_personnel(sftp: bool = False):
    log = f"{TMP}/{GPUC_LOG}_{DATE_DU_JOUR}.log"
    Klogs.setup(log)
    notification = False
    if sftp:
        notification = True
    rb = Gpuc.build_csv_employee(sftp=sftp, notification=notification)
    if rb:
        logger.debug("Création du fichier employée réalisée avec succès")
        sys.exit(0)
    else:
        logger.error("Une erreur est survenue")
        sys.exit(1)


@app.command()
def generate_tree(data_source: Annotated[DataSource, typer.Option(case_sensitive=False)] = DataSource.LDAP.value):
    Klogs.setup()
    gp = Gpuc.build_treeimg(tag=data_source)
    if gp:
        logger.debug("Création du fichier png réalisée avec succès")
        sys.exit(0)
    else:
        logger.error("Une erreur est survenue")
        sys.exit(1)
