import logging
import sys

import typer
from pyetl.config.ohris_settings import GUEST
from pyetl.pipeline.ohris.ohris import Ohris
from pyetl.tools.klogs import Klogs
from typing_extensions import Annotated

app = typer.Typer()


logger = logging.getLogger(__name__)


def luo_callback(value: str) -> list[str]:
    return [x.strip() for x in value.split(",")]


@app.command()
def sampling(
    uo: Annotated[
        str, typer.Option("--liste-uo", "-l", help="Liste uo", callback=luo_callback)
    ] = "HUA81A0000,HUA8120000",
):
    """Echantillonnage avec une liste d'uo version 1.
    Les absences et les données utilisateurs sont directement récupéré via l'api au format adéquat (csv et xml).
    Aucune transformation supplémentaire.
    """
    Klogs.setup()
    luo = uo.split(",")
    flux = Ohris.flux_restricted_perimeter(luo)
    if flux:
        logger.debug("Synchro réalisé avec succès")
        sys.exit(0)
    else:
        logger.error("Une erreur est survenue")
        sys.exit(1)


@app.command()
def partial_sync(
    luo: Annotated[
        str, typer.Option("--liste-uo", "-l", help="Liste uo", callback=luo_callback)
    ] = "HUA81A0000,HUA8120000",
    guest: Annotated[
        bool, typer.Option("--guest", help="Intègre la liste des vip définis dans le fichier ohris_settigns")
    ] = False,
    sftp: Annotated[bool, typer.Option("--sftp", help="Envoie ou non le fichier sur le serveur de'Ohris")] = False,
    prod: Annotated[bool, typer.Option("--prod", help="Envoie sur le serveur de prod ou de test d'Ohris")] = False,
):
    """Synchronisation pariel, uniquement avec la DSI et la DRH (ainsi que leur UO fille)
    Les absences et les données utilisateurs sont récupéré au format json et transformé via le pipeline et
    le modèle Ohris.
    Par défaut, l'envoie des fichiers par sftp sur le serveur d'Ohris est désactivé
    """
    Klogs.setup()
    vip = []
    if guest:
        vip = GUEST
    Ohris.flux_restricted_perimeter_custom(uos=luo, guest=vip, sftp=sftp, prod=prod)


@app.command()
def global_sync(
    guest: Annotated[
        bool, typer.Option("--guest", help="Intègre la liste des vip définis dans le fichier ohris_settigns")
    ] = False,
    sftp: Annotated[bool, typer.Option("--sftp", help="Envoie ou non le fichier sur le serveur de'Ohris")] = False,
    prod: Annotated[bool, typer.Option("--prod", help="Envoie sur le serveur de prod ou de test d'Ohris")] = False,
):
    """Synchronisation global. Tous les agents de l'université qui ont
    Les absences et les données utilisateurs sont récupéré au format json et transformé via le pipeline et
    le modèle Ohris.
    Par défaut, l'envoie des fichiers par sftp sur le serveur d'Ohris est désactivé
    """
    Klogs.setup()
    vip = []
    if guest:
        vip = GUEST
    Ohris.flux_alluniv(guest=vip, sftp=sftp, prod=prod)
