import logging
from datetime import datetime

import typer
from pyetl.config.global_settings import DATE_DU_JOUR, LDHAM_LOG, TMP
from pyetl.pipeline.ldapsiham.ldham import Ldham
from pyetl.tools.klogs import Klogs
from typing_extensions import Annotated

app = typer.Typer()


logger = logging.getLogger(__name__)


@app.command()
def activation_compte(
    date_debut_observation: Annotated[
        datetime,
        typer.Option(
            ...,
            "--date-debut-observation",
            "-b",
            help="Date de début d'observation",
            formats=["%Y-%m-%d", "%Y-%m-%dT%H:%M:%S", "%Y-%m-%d %H:%M:%S", "%d/%m/%Y"],
        ),
    ],
    date_fin_observation: Annotated[
        datetime,
        typer.Option(
            ...,
            "--date-fin-observation",
            "-e",
            help="Date de fin d'observation",
            formats=["%Y-%m-%d", "%Y-%m-%dT%H:%M:%S", "%Y-%m-%d %H:%M:%S", "%d/%m/%Y"],
        ),
    ],
    notification: bool = False,
):
    log = f"{TMP}/{LDHAM_LOG}_{DATE_DU_JOUR}.log"
    Klogs.setup(log)

    ldham = Ldham(date_debut_observation=date_debut_observation, date_fin_observation=date_fin_observation)
    ldham.flux(notification)
