import logging
import sys
from enum import Enum
from pathlib import Path
from typing import Optional

import typer
from pyetl.config.gpuc_settings import SFTP_GPUC
from pyetl.config.ohris_settings import SFTP_OHRIS
from pyetl.tools.klogs import Klogs
from pyetl.tools.sftp import SFTPClient
from typing_extensions import Annotated

app = typer.Typer()

logger = logging.getLogger(__name__)


class Server(str, Enum):
    GPUC: str = "GPUC"
    OHRIS: str = "OHRIS"


@app.command()
def pushf_to_server(
    file: Annotated[str, typer.Argument()],
    server: Annotated[Optional[Server], typer.Option(case_sensitive=False)] = None,
):
    if not Path(file).exists():
        logger.error("Le fichier %s n'existe pas en local", file)
        sys.exit(1)

    if server == Server.GPUC:
        source = SFTP_GPUC
    elif server == Server.OHRIS:
        source = SFTP_OHRIS
    else:
        logger.error("Le serveur doit être renseigné dans le fichier de configuration")
        sys.exit(1)

    Klogs.setup()
    sftp_client = SFTPClient(source["SFTP_HOST"], source["SFTP_PORT"], source["SFTP_USERNAME"], source["SFTP_PASSWORD"])
    sftp_client.connect()
    sftp_client.upload_file(f'{source["PATH_FPROD"]}/{Path(file).name}', file)
    sftp_client.disconnect()


@app.command()
def ls(
    server: Annotated[Server, typer.Argument(case_sensitive=False)] = None,
    path: Annotated[Optional[str], typer.Option("--path", "-p")] = "",
):
    if server == Server.GPUC:
        source = SFTP_GPUC
    elif server == Server.OHRIS:
        source = SFTP_OHRIS
    else:
        logger.error("Le serveur doit être renseigné dans le fichier de configuration")
        sys.exit(1)

    Klogs.setup()
    sftp_client = SFTPClient(source["SFTP_HOST"], source["SFTP_PORT"], source["SFTP_USERNAME"], source["SFTP_PASSWORD"])
    sftp_client.connect()
    sftp_client.get_list_of_files(path)
    sftp_client.disconnect()
