import typer
from pyetl.cli import flux_gpuc, flux_habilitation, flux_ohris, flux_siham, logs, tools
from pyetl.config.global_settings import VERSION

__version__ = VERSION


def version_callback(value: bool):
    if value:
        typer.echo(f"PyETL CLI version: {__version__}")
        raise typer.Exit()


app = typer.Typer()
app.add_typer(
    flux_siham.app,
    name="flux-siham",
    help="Activation ou désactivation de compte HRA pour l'accès au selfservice de SIHAM",
    short_help="Manipulation des comptes HRA SIHAM",
)

app.add_typer(
    flux_habilitation.app,
    name="flux-habilitation",
    help="Gestion des flux habilitations SIHAM",
    short_help="Gestion des flux habilitations SIHAM",
)

app.add_typer(
    flux_ohris.app,
    name="flux-ohris",
    help="Gestion des flux Ohris pour la gestion des congés",
    short_help="Gestion des flux Ohris",
)

app.add_typer(flux_gpuc.app, name="flux-gpuc", help="Gestion des flux Gpuc", short_help="Gestion des flux Gpuc")

app.add_typer(logs.app, name="logs", help="Gestion des fichiers de logs", short_help="Gestion des fichiers de logs")

app.add_typer(tools.app, name="tools", help="Pour tester les outils (sftp, ....)", short_help="Gestion d'outils")


@app.callback()
def main(
    version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True),
) -> None:
    pass
