import logging
import xml.etree.ElementTree as ET
from dataclasses import dataclass, field
from pathlib import Path
from typing import Union

logger = logging.getLogger(__name__)


@dataclass
class Mxml:
    base_file: str
    tree: ET = field(init=False, repr=False)

    def __post_init__(self):
        # Charger le fichier XML existant
        self.tree = ET.parse(self.base_file)

    def add_sxml_to_tree(self, sxml: str) -> None:
        """Crée un fichier xml en combinant un string xml et un fichier xml existant

        Args:
            sxml (str): String xml

        Returns:
            Element Etree
        """
        root = self.tree.getroot()

        # Analyser la chaîne XML
        datasxml = ET.fromstring(sxml)

        # Ajouter chaque nouvelle donnée à l'arbre XML existant
        for data in datasxml:
            root.append(data)

        # Écrire l'arbre XML mis à jour dans le fichier
        # tree.write(new_file, encoding='utf-8', xml_declaration=True)
        logger.debug("MAJ tree")

    def del_agents_from_xml(self, attribut: str, elmt: str) -> None:
        root = self.tree.getroot()
        datap = root.find(f".//utilisateur[{attribut}='{elmt}']")
        if datap:
            root.remove(datap)

        # maj tree
        logger.debug("MAJ tree")

    def tree_to_file(self, outputfile: str):
        self.tree.write(outputfile, encoding="utf-8", xml_declaration=True)

    @staticmethod
    def sxml_to_file(data: Union[str, bytes], *, outputfile: str) -> None:
        """Sauvegarde des données sous format string XML dans un fichier XML

        ** Transform / Load **

        Args:
            data (Union[str, bytes]): Donnée XML sous forme de chaine de caractère
            outputfile (str): Chemin du fichier à sauvegarder

        """
        root = ET.fromstring(data)

        # Créez un arbre XML avec l'élément racine
        tree = ET.ElementTree(root)

        # Écrivez l'arbre XML dans un fichier
        with Path(outputfile).open(mode="wb") as xml_file:
            tree.write(xml_file, encoding="utf-8", xml_declaration=True)
